#include <stdio.h>
#include <stdlib.h>
#include <glib.h>
#include "config.h"


FILE *ink_F;

void create_ink_head()
{
  gchar* jammo_directory=configure_get_jammo_directory();
  gchar *filepath = g_build_filename(jammo_directory, "/motion_inkml.xml", NULL);
  g_free(jammo_directory);
  ink_F = fopen(filepath, "w");
  if(ink_F ==NULL) {
    g_print("Cannot open file INKML..\n");
    exit(EXIT_FAILURE);
  }

  fprintf(ink_F, "<ink xmlns=\"http://www.w3.org/2003/InkML\"documentID=\"uuid:6B29FC40-CA47\"/>\n<trace xml:id=\"password\">\n");

}

void set_xy_in_xml(gfloat x, gfloat y)
{
  int ix=x;
  int iy = y;
  fprintf(ink_F,"%d, %d\n", ix,iy);
}

void create_ink_tale()
{
  fprintf(ink_F,"</trace>\n</ink>");
  fclose(ink_F);
}
